@@ -94,9 +94,12 @@ class PGG_diffusion:
         cost_i = 0
         for i in dealer_neighborhood:
             if self._G.node[i]['strategy'] == 'C' and self._G.node[i]['sent_update'] == 1:
-                Ki = self._G.degree(i)
+                #Ki = self._G.degree(i)
+                Ki = [self._G.node[nd]['strategy'] for nd in self._G.neighbors(i)].count('C')
                 cost_i += 1.0 / (Ki + 1)
-        self._G.node[dealer]['payoff'] = self._synergy * cost_i \
+
+        K = [self._G.node[nd]['strategy'] for nd in self._G.neighbors(dealer)].count('C')
+        self._G.node[dealer]['payoff'] = (self._synergy/(K + 1)) * cost_i \
             - cost_y + noise
 
     def diffusion_step(self):
@@ -133,10 +136,6 @@ class PGG_diffusion:
                 self.set_infected(infected, self._simulation_time)
             self.reset_send_update()
             self.diffusion_step()
-            #for nd in self._G.nodes_iter():
-            #    if self._G.node[nd]['sent_update'] == 1:
-            #        print 'node ', nd, ' sent a packet with time stamp = ', self._G.node[nd]['time_stamp'], ' at simulation time=', self._simulation_time
-            # Update the simuations variable
             self.store_cooperator_defector_counter()
             self.updateStrategy()
             self.reset_payoffs()
